@@ -1,15 +1,34 @@
+/*
+ * Copyright (C) 2011 Red Hat, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ *
+ * The Sushi project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Sushi. This
+ * permission is above and beyond the permissions granted by the GPL license
+ * Sushi is covered by.
+ *
+ * Authors: Cosimo Cecchi <cosimoc@redhat.com>
+ *
+ */
+
 let Constants = imports.util.constants;
 
 let slowDownFactor = 0;
 
-// FIXME: why is this needed?
-function forcedSizeActor(widget) {
-    let actor = new GtkClutter.Actor({ contents: widget });
-    actor.set_size(widget.get_preferred_width()[1], widget.get_preferred_height()[1]);
-
-    return actor;
-}
-
 function setSlowDownFactor(factor) {
     slowDownFactor = factor;
 }
@@ -73,57 +92,35 @@ function getStaticSize(renderer, widget) {
     return [ width, height ];
 }
 
+function createToolButton(iconName, callback) {
+    let button = new Gtk.ToolButton({ expand: false,
+                                      "icon-name": iconName });
+    button.show();
+    button.connect("clicked", callback);
+
+    return button;
+}
+
 function createFullScreenButton(mainWindow) {
-    let toolbarZoom = new Gtk.ToolButton({ expand: false,
-                                           "icon-name": "view-fullscreen-symbolic" });
-    toolbarZoom.show();
-    toolbarZoom.connect("clicked",
-                        function () {
-                            mainWindow.toggleFullScreen();
-                        });
-
-    return toolbarZoom;
+    return createToolButton("view-fullscreen-symbolic", Lang.bind(this, function() {
+        mainWindow.toggleFullScreen();
+    }));        
 }
 
-function createRunButton(file, mainWindow) {
-    let toolbarRun = new Gtk.ToolButton({ expand: false,
-                                          "icon-name": "system-run-symbolic" });
-    toolbarRun.show();
-    toolbarRun.connect("clicked",
-                       function () {
-                           let timestamp = Gtk.get_current_event_time();
-                           try {
-                               Gtk.show_uri(toolbarRun.get_screen(),
-                                            file.get_uri(),
-                                            timestamp);
+function createOpenButton(file, mainWindow) {
+    return createToolButton("document-open-symbolic", Lang.bind(this, function(widget) {
+        let timestamp = Gtk.get_current_event_time();
+        try {
+            Gtk.show_uri(widget.get_screen(),
+                         file.get_uri(),
+                         timestamp);
 
-                               mainWindow.close();
-                           } catch (e) {
-                           }
-                       });
-
-    return toolbarRun;
-}
-
-function createEditButton(file, mainWindow) {
-    // FIXME: needs better icon
-    let toolbarRun = new Gtk.ToolButton({ expand: false,
-                                          "icon-name": "edit-cut-symbolic" });
-    toolbarRun.show();
-    toolbarRun.connect("clicked",
-                       function () {
-                           let timestamp = Gtk.get_current_event_time();
-                           try {
-                               Gtk.show_uri(toolbarRun.get_screen(),
-                                            file.get_uri(),
-                                            timestamp);
-
-                               mainWindow.close();
-                           } catch (e) {
-                           }
-                       });
-
-    return toolbarRun;
+            mainWindow.close();
+        } catch (e) {
+            log('Unable to execute the default application for ' + 
+                file.get_uri() + ' : ' + e.toString());
+        }
+    }));
 }
 
 function formatTimeString(timeVal) {
